% Rechte Seite und Anfangswert
f  = @(t,y) y;
y0 = 2;
t0 = 0;
T  = 1;

% Exakte Loesung
exact_fun = @(t)(y0*exp(t));

% Alloziere Speicherplatz
h    = zeros(7,1);
err1 = zeros(7,1);
err2 = zeros(7,1);

for ii = 0:6
  h(ii+1) = 2^(-ii-3);
  N       = 2^(ii+3);
  % Approximative Loesung
  [t1,y1] = quadraturRK(f,t0,T,y0,N);
  [t2,y2] = klassischeRK(f,t0,T,y0,N);
  % Absoluter Fehler
  % Wert der Referenzloesung zum Zeitpunkt T: exact_fun(T)
  err1(ii+1) = abs(y1(:,end)-exact_fun(T));
  err2(ii+1) = abs(y2(:,end)-exact_fun(T));
end

% loglog-plot
figure(1);
loglog(h,err1,'-*');
hold on;
loglog(h,err2,'-*');
xlabel('h');
ylabel('|y_N - y(T)|');
grid on;
legend('quadraturRK', 'klassischeRK');
hold off;

% Konvergenzrate
fit1 = polyfit(log(h),log(err1),1);
fprintf('Empirische Konvergenzrate fuer quadraturRK : %1.2f\n',fit1(1))
fit2 = polyfit(log(h),log(err2),1);
fprintf('Empirische Konvergenzrate fuer klassischeRK: %1.2f\n',fit2(1))
